var group__PkgTriangulationOnSphere2TriangulationClasses =
[
    [ "CGAL::Delaunay_triangulation_on_sphere_2< Traits, TDS >", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html", [
      [ "Geom_traits", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#aba2ab15d0e6b0c0f7f71a1767b5b5aca", null ],
      [ "Point", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a295dfed8bd54faa5c2404c09e30acdda", null ],
      [ "Delaunay_triangulation_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#aaf23cbd9fef31230bf4c2cbc6fc11f8e", null ],
      [ "Delaunay_triangulation_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#afa69966c7ebbb4fe172d962d4d38ff67", null ],
      [ "Delaunay_triangulation_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a1fff40c879ca8ba44d14d354ecf2200b", null ],
      [ "Delaunay_triangulation_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a74de0d03004d394d3d51c7def896c595", null ],
      [ "Delaunay_triangulation_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ad8b32d8bc75e9fb527e7069a0ced7a70", null ],
      [ "dual", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ad69bbc3e97aa9b346e87b9f1ae7fc3a0", null ],
      [ "dual", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a917507c1f208bda4e103ff6e968311f8", null ],
      [ "dual", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a714ebac8bf8ff3042644f84492f8d3fb", null ],
      [ "dual", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a0b1d32e620b7522606670b0ed5858142", null ],
      [ "dual_on_sphere", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ac7403a86022a535d14d75ce3a0b84370", null ],
      [ "dual_on_sphere", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ab04c29d1196edf08823156ac4acfa3d7", null ],
      [ "dual_on_sphere", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a6e74342e90b637989353e97658aaac85", null ],
      [ "dual_on_sphere", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ab67e4c0620b7c500e0d7629a6e256af7", null ],
      [ "get_conflicts_and_boundary", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#aea2f440a6add710a1aecee7e841b1013", null ],
      [ "insert", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a528b38fdbcf384953e90e3514fc398ac", null ],
      [ "insert", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a8a599356d6fb101aa7122b8fb88b168a", null ],
      [ "insert", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ad4514b958d3e833cb77d1d288dc83b14", null ],
      [ "is_valid", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ad4cb73f08b56a1ca41c9734a37a6dbf9", null ],
      [ "push_back", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a176258dbf24328ac4d3fde54e5eb0b26", null ],
      [ "remove", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a4ec4a8d0adec85a5e68eeb73951b901c", null ],
      [ "side_of_oriented_circle", "classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a34509a2547240f9234c76e941c842cce", null ]
    ] ],
    [ "CGAL::Delaunay_triangulation_on_sphere_traits_2< LK, SK >", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html", [
      [ "Arc_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#af8975d8dbc1d273b9070c8aebd8a72bd", null ],
      [ "Collinear_are_strictly_ordered_on_great_circle_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#af58e88bce84c05a3428784e4313e2225", null ],
      [ "Compare_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#aeaab6ea8046f4a070eb0a3082b23a575", null ],
      [ "Construct_arc_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a96e6e79a151a44fc216027c2afc9be95", null ],
      [ "Construct_circumcenter_3", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a69798fee2314576e1a4b7b8f284d7f16", null ],
      [ "Construct_point_3", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#ae6a4775ff6faa6bbbf24697dd3e67935", null ],
      [ "Construct_segment_3", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a21eb6038d4b9418605495ac5b05b9005", null ],
      [ "Construct_triangle_3", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#aa037f0aee458aec9d9fec0d710230c53", null ],
      [ "Equal_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a6ccbd74fd9565dc73976c30af9648a59", null ],
      [ "FT", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#af32c4ba813d3dce12b65f58f2453a615", null ],
      [ "Orientation_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a33d5d7ac61c7efdf986672dcacd91f43", null ],
      [ "Point_3", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a2579d79f9c9480f3c16b9e509d9126ab", null ],
      [ "Point_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a0382911b98a55b2ee4bdb2ac493961a0", null ],
      [ "Segment_3", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a444ba203f293262bf9b0747ecd872d69", null ],
      [ "Side_of_oriented_circle_on_sphere_2", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a7a14aee6791eda7fa5bc3f2c55055e07", null ],
      [ "Triangle_3", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a740e41f4f0980eb4e3a1637071d17e09", null ],
      [ "are_points_too_close", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a7d9220bca8d0b95b4bd37767779e7336", null ],
      [ "is_on_sphere", "classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#ae0f10c1be572af5d813b897ea6251d71", null ]
    ] ],
    [ "CGAL::Projection_on_sphere_traits_3< LK, SK >", "classCGAL_1_1Projection__on__sphere__traits__3.html", [
      [ "Arc_on_sphere_2", "classCGAL_1_1Projection__on__sphere__traits__3.html#a423cc82220432d1ffedc48747a35ae5a", null ],
      [ "Equal_on_sphere_2", "classCGAL_1_1Projection__on__sphere__traits__3.html#a375e158bb5c306d216132f663f00d847", null ],
      [ "FT", "classCGAL_1_1Projection__on__sphere__traits__3.html#a0b0e6576e8d12b2ac505341557211d53", null ],
      [ "Point_3", "classCGAL_1_1Projection__on__sphere__traits__3.html#ab17ab4776f4ea2d929ecf5b4070141ea", null ],
      [ "Point_on_sphere_2", "classCGAL_1_1Projection__on__sphere__traits__3.html#a20fe864cd37faa8230d413c717ea0ee3", null ],
      [ "Segment_3", "classCGAL_1_1Projection__on__sphere__traits__3.html#acedb61884b014cd9cf1de5e3e5ff5111", null ],
      [ "Triangle_3", "classCGAL_1_1Projection__on__sphere__traits__3.html#aa4c8edc95f0f43fa12d5c9af783d8d39", null ],
      [ "are_points_too_close", "classCGAL_1_1Projection__on__sphere__traits__3.html#ac1b3f2510b150af5ee63c57a46b287e6", null ],
      [ "is_on_sphere", "classCGAL_1_1Projection__on__sphere__traits__3.html#ae331b210f14afa75e4d0707886bacf9d", null ]
    ] ],
    [ "CGAL::Triangulation_on_sphere_2< Traits, TDS >", "classCGAL_1_1Triangulation__on__sphere__2.html", [
      [ "All_edges", "classCGAL_1_1Triangulation__on__sphere__2.html#a78b0e6bcf13d31f583f2dd80f7358508", null ],
      [ "All_edges_iterator", "classCGAL_1_1Triangulation__on__sphere__2.html#ad6e3450f964ef4ce9a201e8fa4e3c9ac", null ],
      [ "All_face_handles", "classCGAL_1_1Triangulation__on__sphere__2.html#a5a7c4058b2a581af52820678a6d42c42", null ],
      [ "All_faces_iterator", "classCGAL_1_1Triangulation__on__sphere__2.html#a31e90961175ec0ddd72df7eb9440938d", null ],
      [ "Arc_on_sphere_2", "classCGAL_1_1Triangulation__on__sphere__2.html#a580f0b0bd168a95aed33f83d3d98c11d", null ],
      [ "Edge", "classCGAL_1_1Triangulation__on__sphere__2.html#a82d32668830c6e80787aefbecd8c149b", null ],
      [ "Edge_circulator", "classCGAL_1_1Triangulation__on__sphere__2.html#adf4dde8d241fda17052d8eae08c2bdfc", null ],
      [ "Face", "classCGAL_1_1Triangulation__on__sphere__2.html#a713c3c5ecb019409d2fa5e18ff76a0ba", null ],
      [ "Face_circulator", "classCGAL_1_1Triangulation__on__sphere__2.html#a79b3ccccb787702a803099dbb8d153c9", null ],
      [ "Face_handle", "classCGAL_1_1Triangulation__on__sphere__2.html#a59e920fda7395347eeb9b83fd0ee8743", null ],
      [ "FT", "classCGAL_1_1Triangulation__on__sphere__2.html#a2d8b7777e2d52d559c2d852f022f4c15", null ],
      [ "Geom_traits", "classCGAL_1_1Triangulation__on__sphere__2.html#a83cedc161f4fedc83790de4a5f1c8b66", null ],
      [ "Point", "classCGAL_1_1Triangulation__on__sphere__2.html#adbf2438e4b0d78f6af214a37f6c262d9", null ],
      [ "Point_3", "classCGAL_1_1Triangulation__on__sphere__2.html#a2a9ceda7b558cb8543b76da093774536", null ],
      [ "Point_iterator", "classCGAL_1_1Triangulation__on__sphere__2.html#a10da4cc8bf560a04e12e88e707c0b80f", null ],
      [ "Points", "classCGAL_1_1Triangulation__on__sphere__2.html#a4a921522cb870d1204cc6ea1632d5ff8", null ],
      [ "Segment_3", "classCGAL_1_1Triangulation__on__sphere__2.html#a3782668eaabbbadbb34eb326c789cc57", null ],
      [ "size_type", "classCGAL_1_1Triangulation__on__sphere__2.html#a38ab81aa3d0471998c8095f585ebc6f0", null ],
      [ "Solid_edges", "classCGAL_1_1Triangulation__on__sphere__2.html#ab04547a5ed211fb2af5ceb98272bcd3c", null ],
      [ "Solid_edges_iterator", "classCGAL_1_1Triangulation__on__sphere__2.html#afe67955ea61d7880cfde6711997c984a", null ],
      [ "Solid_face_handles", "classCGAL_1_1Triangulation__on__sphere__2.html#ae99403c8011c2b6cb084b4d38fec1bfc", null ],
      [ "Solid_faces_iterator", "classCGAL_1_1Triangulation__on__sphere__2.html#ab0bac2f0b31c53c793da28088cf74171", null ],
      [ "Triangle_3", "classCGAL_1_1Triangulation__on__sphere__2.html#a13945f9b7898f1307150bf1645d0593d", null ],
      [ "Triangulation_data_structure", "classCGAL_1_1Triangulation__on__sphere__2.html#a71262c6f8154440c0a46b35874743307", null ],
      [ "Vertex", "classCGAL_1_1Triangulation__on__sphere__2.html#adac882d27a9c24379440ce68d79e6c92", null ],
      [ "Vertex_circulator", "classCGAL_1_1Triangulation__on__sphere__2.html#a1d5958f1f28264f515e0592906482a36", null ],
      [ "Vertex_handle", "classCGAL_1_1Triangulation__on__sphere__2.html#af0578ac9faf8649c54246b34e9c79ffe", null ],
      [ "Vertex_handles", "classCGAL_1_1Triangulation__on__sphere__2.html#a1c66dcccc58c3e12e14ae675d2cb5030", null ],
      [ "Vertices_iterator", "classCGAL_1_1Triangulation__on__sphere__2.html#a7ea02bf43866228055fbb8a97adde8d1", null ],
      [ "Locate_type", "classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368", [
        [ "VERTEX", "classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368a9054358245c71aec15608ef850a47696", null ],
        [ "EDGE", "classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368a1fafd87c207c51dba17ff7bedbb9a7d5", null ],
        [ "FACE", "classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368a2ce43eac395c1e002fe8325b9679f7b0", null ],
        [ "OUTSIDE_CONVEX_HULL", "classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368ad9946ac171a3616baf474b692111ffdc", null ],
        [ "OUTSIDE_AFFINE_HULL", "classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368a085da3d409df0ce77cec7e3883048f84", null ],
        [ "NOT_ON_SPHERE", "classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368a8e685483f2b164f1fbaacd5b26b0d570", null ],
        [ "TOO_CLOSE", "classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368a8e335bd92ce14c8b9faedeb7e1c7d32d", null ]
      ] ],
      [ "Triangulation_on_sphere_2", "classCGAL_1_1Triangulation__on__sphere__2.html#abb251d75397d86feb4b29c520722a448", null ],
      [ "Triangulation_on_sphere_2", "classCGAL_1_1Triangulation__on__sphere__2.html#a09817eec2b69440e23dd95409fd6a18e", null ],
      [ "Triangulation_on_sphere_2", "classCGAL_1_1Triangulation__on__sphere__2.html#ae41c9ffcd59aa74460032d6841ebe3ee", null ],
      [ "adjacent_vertices", "classCGAL_1_1Triangulation__on__sphere__2.html#aa77bff97e3bd3adc78bb6efbd1a60c10", null ],
      [ "adjacent_vertices", "classCGAL_1_1Triangulation__on__sphere__2.html#ad2b2c32e7ab6f41b27fe94589514398b", null ],
      [ "all_edges", "classCGAL_1_1Triangulation__on__sphere__2.html#a17cf0e76976af979a0f2590317a5ef81", null ],
      [ "all_edges_begin", "classCGAL_1_1Triangulation__on__sphere__2.html#aee414c526af8777c9f13dcf6c5df92ab", null ],
      [ "all_edges_end", "classCGAL_1_1Triangulation__on__sphere__2.html#a045d9f92f669be1723600f8454a82da0", null ],
      [ "all_face_handles", "classCGAL_1_1Triangulation__on__sphere__2.html#aff0ff910e5a4c9158228518469a289fc", null ],
      [ "all_faces_begin", "classCGAL_1_1Triangulation__on__sphere__2.html#af1541edded92f0d6ab0d7b3c105917e1", null ],
      [ "all_faces_end", "classCGAL_1_1Triangulation__on__sphere__2.html#ac94b8b39af6976764fce6215a5077b42", null ],
      [ "clear", "classCGAL_1_1Triangulation__on__sphere__2.html#a55718ca8fcf8b7118f5c8e66a06c1609", null ],
      [ "dimension", "classCGAL_1_1Triangulation__on__sphere__2.html#a38d4d87e037ab84a86d40c8a58390801", null ],
      [ "geom_traits", "classCGAL_1_1Triangulation__on__sphere__2.html#a4972d0047f71cad49f3e01dae5ea5788", null ],
      [ "incident_edges", "classCGAL_1_1Triangulation__on__sphere__2.html#a0c4985cf6b2bbc22d150c2473860de09", null ],
      [ "incident_edges", "classCGAL_1_1Triangulation__on__sphere__2.html#a46cf5fb66ea5d670fdf5d909b4ad614a", null ],
      [ "incident_faces", "classCGAL_1_1Triangulation__on__sphere__2.html#a6fd7a0383a88681376e8f6d32fc5aae0", null ],
      [ "incident_faces", "classCGAL_1_1Triangulation__on__sphere__2.html#a70648c8f333f770bf281fbed6610cfe3", null ],
      [ "is_edge", "classCGAL_1_1Triangulation__on__sphere__2.html#a0a5e73e02746d5805cd66ddbe8666b1f", null ],
      [ "is_edge", "classCGAL_1_1Triangulation__on__sphere__2.html#ad8d9c6bde74b4a2c346e9c3070bccc33", null ],
      [ "is_face", "classCGAL_1_1Triangulation__on__sphere__2.html#aca1455b13cb34a477aa901547b53f75e", null ],
      [ "is_face", "classCGAL_1_1Triangulation__on__sphere__2.html#ad8d8ed5aefab4009a5c04c9dd1e5a7bf", null ],
      [ "is_ghost", "classCGAL_1_1Triangulation__on__sphere__2.html#a78e3e0f198bd1fc017dfbc8599cd6fa8", null ],
      [ "is_ghost", "classCGAL_1_1Triangulation__on__sphere__2.html#a0b9f9b2a795d7cbe57f9148fd9134bb1", null ],
      [ "is_valid", "classCGAL_1_1Triangulation__on__sphere__2.html#a8aaacdcdb77ede1d09af712a37664cb6", null ],
      [ "locate", "classCGAL_1_1Triangulation__on__sphere__2.html#a53acc07d925f00b4a66979c9dbc99f29", null ],
      [ "locate", "classCGAL_1_1Triangulation__on__sphere__2.html#a5e784cdf403691ccb7f33d6548dea6df", null ],
      [ "number_of_faces", "classCGAL_1_1Triangulation__on__sphere__2.html#af858392dd142c5f7b024f4b4f1c6bb11", null ],
      [ "number_of_ghost_faces", "classCGAL_1_1Triangulation__on__sphere__2.html#a56f201bc7550eebf57c41a364f4afc7e", null ],
      [ "number_of_solid_faces", "classCGAL_1_1Triangulation__on__sphere__2.html#ae7f0deae8f142f4ec03e33ea794a373c", null ],
      [ "number_of_vertices", "classCGAL_1_1Triangulation__on__sphere__2.html#aa7379e9213d72593fe5080f8e4407ebb", null ],
      [ "operator=", "classCGAL_1_1Triangulation__on__sphere__2.html#ad23082a6839e0f7cabada1385928f4f3", null ],
      [ "point", "classCGAL_1_1Triangulation__on__sphere__2.html#a221c8c618dad2d73c69c0ac6fd70a463", null ],
      [ "point", "classCGAL_1_1Triangulation__on__sphere__2.html#a0b86fe9152f891272def95cacf6598bb", null ],
      [ "points", "classCGAL_1_1Triangulation__on__sphere__2.html#af60a99e81419bf43d457924d78697154", null ],
      [ "segment", "classCGAL_1_1Triangulation__on__sphere__2.html#a67bf1c3b2d51885487819d59622b4ef2", null ],
      [ "segment", "classCGAL_1_1Triangulation__on__sphere__2.html#a15b9150c44e9b2beb31c7d6af649b16c", null ],
      [ "segment_on_sphere", "classCGAL_1_1Triangulation__on__sphere__2.html#af54cb7ecf4defe0760c0e87e7acf317a", null ],
      [ "segment_on_sphere", "classCGAL_1_1Triangulation__on__sphere__2.html#afbf28789c8f1721b8fa78e2cff05f344", null ],
      [ "set_center", "classCGAL_1_1Triangulation__on__sphere__2.html#a211810561992740f2350f7f0c5cd8a8a", null ],
      [ "set_center_and_radius", "classCGAL_1_1Triangulation__on__sphere__2.html#abb242907b37f4ee1bc02ce8ddbd91a41", null ],
      [ "set_radius", "classCGAL_1_1Triangulation__on__sphere__2.html#aa98b1c1b47bbe751a02a42268cb013d9", null ],
      [ "solid_edges", "classCGAL_1_1Triangulation__on__sphere__2.html#ad7264cfa113ca9cad9022cf68e00c3c9", null ],
      [ "solid_edges_begin", "classCGAL_1_1Triangulation__on__sphere__2.html#a7d140a659c5fae73282a9f1ac4923e68", null ],
      [ "solid_edges_end", "classCGAL_1_1Triangulation__on__sphere__2.html#aee69f5d92abcf78a510beb697558c7eb", null ],
      [ "solid_face_handles", "classCGAL_1_1Triangulation__on__sphere__2.html#ab190d3933b157fcc4dab06ba7967e4c8", null ],
      [ "solid_faces_begin", "classCGAL_1_1Triangulation__on__sphere__2.html#aa7cdafb9d3e3a037867283ad5354be67", null ],
      [ "solid_faces_end", "classCGAL_1_1Triangulation__on__sphere__2.html#a75ae3c710864e895e56a33a324e7e217", null ],
      [ "swap", "classCGAL_1_1Triangulation__on__sphere__2.html#ad84dcc82df42f27cb53f87c076f306a5", null ],
      [ "tds", "classCGAL_1_1Triangulation__on__sphere__2.html#a9d518722559720a863563385011bfa95", null ],
      [ "triangle", "classCGAL_1_1Triangulation__on__sphere__2.html#ac9af62da049168122f6fb8fec2be6b2c", null ],
      [ "vertex_handles", "classCGAL_1_1Triangulation__on__sphere__2.html#a28294cf36820d583459bbaf8a912dea1", null ],
      [ "vertices_begin", "classCGAL_1_1Triangulation__on__sphere__2.html#a972d571584525af1ce6a9b8c1e0e7ff8", null ],
      [ "vertices_end", "classCGAL_1_1Triangulation__on__sphere__2.html#a34a0c7dd74376c6ac1fd8f1f4925776d", null ]
    ] ]
];